"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from mesa_sdk import errors, models, utils
from mesa_sdk._hooks import HookContext
from mesa_sdk.types import OptionalNullable, UNSET
from mesa_sdk.utils.unmarshal_json_response import unmarshal_json_response
from typing import Any, List, Mapping, Optional


class Admin(BaseSDK):
    def create_api_key(
        self,
        *,
        org: str,
        name: Optional[str] = None,
        scopes: Optional[List[models.Scope]] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PostByOrgAPIKeysResponse:
        r"""Create API key

        Create a new API key for programmatic access

        :param org:
        :param name:
        :param scopes:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.PostByOrgAPIKeysRequest(
            org=org,
            body=models.PostByOrgAPIKeysRequestBody(
                name=name,
                scopes=scopes,
            ),
        )

        req = self._build_request(
            method="POST",
            path="/{org}/api-keys",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.body,
                False,
                True,
                "json",
                Optional[models.PostByOrgAPIKeysRequestBody],
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="postByOrgApiKeys",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "406",
                "409",
                "4XX",
                "500",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "201", "application/json"):
            return unmarshal_json_response(models.PostByOrgAPIKeysResponse, http_res)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgAPIKeysBadRequestErrorData, http_res
            )
            raise errors.PostByOrgAPIKeysBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgAPIKeysUnauthorizedErrorData, http_res
            )
            raise errors.PostByOrgAPIKeysUnauthorizedError(response_data, http_res)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgAPIKeysForbiddenErrorData, http_res
            )
            raise errors.PostByOrgAPIKeysForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgAPIKeysNotFoundErrorData, http_res
            )
            raise errors.PostByOrgAPIKeysNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "406", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgAPIKeysNotAcceptableErrorData, http_res
            )
            raise errors.PostByOrgAPIKeysNotAcceptableError(response_data, http_res)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgAPIKeysConflictErrorData, http_res
            )
            raise errors.PostByOrgAPIKeysConflictError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgAPIKeysInternalServerErrorData, http_res
            )
            raise errors.PostByOrgAPIKeysInternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)

        raise errors.MesaDefaultError("Unexpected response received", http_res)

    async def create_api_key_async(
        self,
        *,
        org: str,
        name: Optional[str] = None,
        scopes: Optional[List[models.Scope]] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PostByOrgAPIKeysResponse:
        r"""Create API key

        Create a new API key for programmatic access

        :param org:
        :param name:
        :param scopes:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.PostByOrgAPIKeysRequest(
            org=org,
            body=models.PostByOrgAPIKeysRequestBody(
                name=name,
                scopes=scopes,
            ),
        )

        req = self._build_request_async(
            method="POST",
            path="/{org}/api-keys",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.body,
                False,
                True,
                "json",
                Optional[models.PostByOrgAPIKeysRequestBody],
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="postByOrgApiKeys",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "406",
                "409",
                "4XX",
                "500",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "201", "application/json"):
            return unmarshal_json_response(models.PostByOrgAPIKeysResponse, http_res)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgAPIKeysBadRequestErrorData, http_res
            )
            raise errors.PostByOrgAPIKeysBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgAPIKeysUnauthorizedErrorData, http_res
            )
            raise errors.PostByOrgAPIKeysUnauthorizedError(response_data, http_res)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgAPIKeysForbiddenErrorData, http_res
            )
            raise errors.PostByOrgAPIKeysForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgAPIKeysNotFoundErrorData, http_res
            )
            raise errors.PostByOrgAPIKeysNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "406", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgAPIKeysNotAcceptableErrorData, http_res
            )
            raise errors.PostByOrgAPIKeysNotAcceptableError(response_data, http_res)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgAPIKeysConflictErrorData, http_res
            )
            raise errors.PostByOrgAPIKeysConflictError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgAPIKeysInternalServerErrorData, http_res
            )
            raise errors.PostByOrgAPIKeysInternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)

        raise errors.MesaDefaultError("Unexpected response received", http_res)

    def list_api_keys(
        self,
        *,
        org: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.GetByOrgAPIKeysResponse:
        r"""List API keys

        List all API keys for the organization (key values are not returned)

        :param org:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetByOrgAPIKeysRequest(
            org=org,
        )

        req = self._build_request(
            method="GET",
            path="/{org}/api-keys",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="getByOrgApiKeys",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "406",
                "409",
                "4XX",
                "500",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.GetByOrgAPIKeysResponse, http_res)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgAPIKeysBadRequestErrorData, http_res
            )
            raise errors.GetByOrgAPIKeysBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgAPIKeysUnauthorizedErrorData, http_res
            )
            raise errors.GetByOrgAPIKeysUnauthorizedError(response_data, http_res)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgAPIKeysForbiddenErrorData, http_res
            )
            raise errors.GetByOrgAPIKeysForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgAPIKeysNotFoundErrorData, http_res
            )
            raise errors.GetByOrgAPIKeysNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "406", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgAPIKeysNotAcceptableErrorData, http_res
            )
            raise errors.GetByOrgAPIKeysNotAcceptableError(response_data, http_res)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgAPIKeysConflictErrorData, http_res
            )
            raise errors.GetByOrgAPIKeysConflictError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgAPIKeysInternalServerErrorData, http_res
            )
            raise errors.GetByOrgAPIKeysInternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)

        raise errors.MesaDefaultError("Unexpected response received", http_res)

    async def list_api_keys_async(
        self,
        *,
        org: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.GetByOrgAPIKeysResponse:
        r"""List API keys

        List all API keys for the organization (key values are not returned)

        :param org:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetByOrgAPIKeysRequest(
            org=org,
        )

        req = self._build_request_async(
            method="GET",
            path="/{org}/api-keys",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="getByOrgApiKeys",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "406",
                "409",
                "4XX",
                "500",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.GetByOrgAPIKeysResponse, http_res)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgAPIKeysBadRequestErrorData, http_res
            )
            raise errors.GetByOrgAPIKeysBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgAPIKeysUnauthorizedErrorData, http_res
            )
            raise errors.GetByOrgAPIKeysUnauthorizedError(response_data, http_res)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgAPIKeysForbiddenErrorData, http_res
            )
            raise errors.GetByOrgAPIKeysForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgAPIKeysNotFoundErrorData, http_res
            )
            raise errors.GetByOrgAPIKeysNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "406", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgAPIKeysNotAcceptableErrorData, http_res
            )
            raise errors.GetByOrgAPIKeysNotAcceptableError(response_data, http_res)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgAPIKeysConflictErrorData, http_res
            )
            raise errors.GetByOrgAPIKeysConflictError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgAPIKeysInternalServerErrorData, http_res
            )
            raise errors.GetByOrgAPIKeysInternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)

        raise errors.MesaDefaultError("Unexpected response received", http_res)

    def revoke_api_key(
        self,
        *,
        id: str,
        org: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.DeleteByOrgAPIKeysByIDResponse:
        r"""Revoke API key

        Revoke an API key by its ID

        :param id:
        :param org:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.DeleteByOrgAPIKeysByIDRequest(
            id=id,
            org=org,
        )

        req = self._build_request(
            method="DELETE",
            path="/{org}/api-keys/{id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="deleteByOrgApiKeysById",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "406",
                "409",
                "4XX",
                "500",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.DeleteByOrgAPIKeysByIDResponse, http_res
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgAPIKeysByIDBadRequestErrorData, http_res
            )
            raise errors.DeleteByOrgAPIKeysByIDBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgAPIKeysByIDUnauthorizedErrorData, http_res
            )
            raise errors.DeleteByOrgAPIKeysByIDUnauthorizedError(
                response_data, http_res
            )
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgAPIKeysByIDForbiddenErrorData, http_res
            )
            raise errors.DeleteByOrgAPIKeysByIDForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgAPIKeysByIDNotFoundErrorData, http_res
            )
            raise errors.DeleteByOrgAPIKeysByIDNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "406", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgAPIKeysByIDNotAcceptableErrorData, http_res
            )
            raise errors.DeleteByOrgAPIKeysByIDNotAcceptableError(
                response_data, http_res
            )
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgAPIKeysByIDConflictErrorData, http_res
            )
            raise errors.DeleteByOrgAPIKeysByIDConflictError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgAPIKeysByIDInternalServerErrorData, http_res
            )
            raise errors.DeleteByOrgAPIKeysByIDInternalServerError(
                response_data, http_res
            )
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)

        raise errors.MesaDefaultError("Unexpected response received", http_res)

    async def revoke_api_key_async(
        self,
        *,
        id: str,
        org: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.DeleteByOrgAPIKeysByIDResponse:
        r"""Revoke API key

        Revoke an API key by its ID

        :param id:
        :param org:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.DeleteByOrgAPIKeysByIDRequest(
            id=id,
            org=org,
        )

        req = self._build_request_async(
            method="DELETE",
            path="/{org}/api-keys/{id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="deleteByOrgApiKeysById",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "406",
                "409",
                "4XX",
                "500",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.DeleteByOrgAPIKeysByIDResponse, http_res
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgAPIKeysByIDBadRequestErrorData, http_res
            )
            raise errors.DeleteByOrgAPIKeysByIDBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgAPIKeysByIDUnauthorizedErrorData, http_res
            )
            raise errors.DeleteByOrgAPIKeysByIDUnauthorizedError(
                response_data, http_res
            )
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgAPIKeysByIDForbiddenErrorData, http_res
            )
            raise errors.DeleteByOrgAPIKeysByIDForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgAPIKeysByIDNotFoundErrorData, http_res
            )
            raise errors.DeleteByOrgAPIKeysByIDNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "406", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgAPIKeysByIDNotAcceptableErrorData, http_res
            )
            raise errors.DeleteByOrgAPIKeysByIDNotAcceptableError(
                response_data, http_res
            )
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgAPIKeysByIDConflictErrorData, http_res
            )
            raise errors.DeleteByOrgAPIKeysByIDConflictError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgAPIKeysByIDInternalServerErrorData, http_res
            )
            raise errors.DeleteByOrgAPIKeysByIDInternalServerError(
                response_data, http_res
            )
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)

        raise errors.MesaDefaultError("Unexpected response received", http_res)
