"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from mesa_sdk import errors, models, utils
from mesa_sdk._hooks import HookContext
from mesa_sdk.types import OptionalNullable, UNSET
from mesa_sdk.utils.unmarshal_json_response import unmarshal_json_response
from typing import Any, List, Mapping, Optional


class Webhooks(BaseSDK):
    def list(
        self,
        *,
        org: str,
        repo: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.GetByOrgByRepoWebhooksResponse:
        r"""List webhooks

        List webhooks for a repository

        :param org:
        :param repo:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetByOrgByRepoWebhooksRequest(
            org=org,
            repo=repo,
        )

        req = self._build_request(
            method="GET",
            path="/{org}/{repo}/webhooks",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="getByOrgByRepoWebhooks",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "406",
                "409",
                "4XX",
                "500",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.GetByOrgByRepoWebhooksResponse, http_res
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoWebhooksBadRequestErrorData, http_res
            )
            raise errors.GetByOrgByRepoWebhooksBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoWebhooksUnauthorizedErrorData, http_res
            )
            raise errors.GetByOrgByRepoWebhooksUnauthorizedError(
                response_data, http_res
            )
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoWebhooksForbiddenErrorData, http_res
            )
            raise errors.GetByOrgByRepoWebhooksForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoWebhooksNotFoundErrorData, http_res
            )
            raise errors.GetByOrgByRepoWebhooksNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "406", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoWebhooksNotAcceptableErrorData, http_res
            )
            raise errors.GetByOrgByRepoWebhooksNotAcceptableError(
                response_data, http_res
            )
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoWebhooksConflictErrorData, http_res
            )
            raise errors.GetByOrgByRepoWebhooksConflictError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoWebhooksInternalServerErrorData, http_res
            )
            raise errors.GetByOrgByRepoWebhooksInternalServerError(
                response_data, http_res
            )
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)

        raise errors.MesaDefaultError("Unexpected response received", http_res)

    async def list_async(
        self,
        *,
        org: str,
        repo: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.GetByOrgByRepoWebhooksResponse:
        r"""List webhooks

        List webhooks for a repository

        :param org:
        :param repo:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetByOrgByRepoWebhooksRequest(
            org=org,
            repo=repo,
        )

        req = self._build_request_async(
            method="GET",
            path="/{org}/{repo}/webhooks",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="getByOrgByRepoWebhooks",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "406",
                "409",
                "4XX",
                "500",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.GetByOrgByRepoWebhooksResponse, http_res
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoWebhooksBadRequestErrorData, http_res
            )
            raise errors.GetByOrgByRepoWebhooksBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoWebhooksUnauthorizedErrorData, http_res
            )
            raise errors.GetByOrgByRepoWebhooksUnauthorizedError(
                response_data, http_res
            )
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoWebhooksForbiddenErrorData, http_res
            )
            raise errors.GetByOrgByRepoWebhooksForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoWebhooksNotFoundErrorData, http_res
            )
            raise errors.GetByOrgByRepoWebhooksNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "406", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoWebhooksNotAcceptableErrorData, http_res
            )
            raise errors.GetByOrgByRepoWebhooksNotAcceptableError(
                response_data, http_res
            )
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoWebhooksConflictErrorData, http_res
            )
            raise errors.GetByOrgByRepoWebhooksConflictError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoWebhooksInternalServerErrorData, http_res
            )
            raise errors.GetByOrgByRepoWebhooksInternalServerError(
                response_data, http_res
            )
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)

        raise errors.MesaDefaultError("Unexpected response received", http_res)

    def create(
        self,
        *,
        org: str,
        repo: str,
        url: str,
        events: Optional[List[models.EventRequest]] = None,
        branches: Optional[List[str]] = None,
        globs: Optional[List[str]] = None,
        secret: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PostByOrgByRepoWebhooksResponse:
        r"""Create webhook

        Create a webhook for a repository

        :param org:
        :param repo:
        :param url:
        :param events:
        :param branches:
        :param globs:
        :param secret:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.PostByOrgByRepoWebhooksRequest(
            org=org,
            repo=repo,
            body=models.PostByOrgByRepoWebhooksRequestBody(
                url=url,
                events=events,
                branches=branches,
                globs=globs,
                secret=secret,
            ),
        )

        req = self._build_request(
            method="POST",
            path="/{org}/{repo}/webhooks",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.body,
                False,
                True,
                "json",
                Optional[models.PostByOrgByRepoWebhooksRequestBody],
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="postByOrgByRepoWebhooks",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "406",
                "409",
                "4XX",
                "500",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "201", "application/json"):
            return unmarshal_json_response(
                models.PostByOrgByRepoWebhooksResponse, http_res
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgByRepoWebhooksBadRequestErrorData, http_res
            )
            raise errors.PostByOrgByRepoWebhooksBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgByRepoWebhooksUnauthorizedErrorData, http_res
            )
            raise errors.PostByOrgByRepoWebhooksUnauthorizedError(
                response_data, http_res
            )
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgByRepoWebhooksForbiddenErrorData, http_res
            )
            raise errors.PostByOrgByRepoWebhooksForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgByRepoWebhooksNotFoundErrorData, http_res
            )
            raise errors.PostByOrgByRepoWebhooksNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "406", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgByRepoWebhooksNotAcceptableErrorData, http_res
            )
            raise errors.PostByOrgByRepoWebhooksNotAcceptableError(
                response_data, http_res
            )
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgByRepoWebhooksConflictErrorData, http_res
            )
            raise errors.PostByOrgByRepoWebhooksConflictError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgByRepoWebhooksInternalServerErrorData, http_res
            )
            raise errors.PostByOrgByRepoWebhooksInternalServerError(
                response_data, http_res
            )
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)

        raise errors.MesaDefaultError("Unexpected response received", http_res)

    async def create_async(
        self,
        *,
        org: str,
        repo: str,
        url: str,
        events: Optional[List[models.EventRequest]] = None,
        branches: Optional[List[str]] = None,
        globs: Optional[List[str]] = None,
        secret: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PostByOrgByRepoWebhooksResponse:
        r"""Create webhook

        Create a webhook for a repository

        :param org:
        :param repo:
        :param url:
        :param events:
        :param branches:
        :param globs:
        :param secret:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.PostByOrgByRepoWebhooksRequest(
            org=org,
            repo=repo,
            body=models.PostByOrgByRepoWebhooksRequestBody(
                url=url,
                events=events,
                branches=branches,
                globs=globs,
                secret=secret,
            ),
        )

        req = self._build_request_async(
            method="POST",
            path="/{org}/{repo}/webhooks",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.body,
                False,
                True,
                "json",
                Optional[models.PostByOrgByRepoWebhooksRequestBody],
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="postByOrgByRepoWebhooks",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "406",
                "409",
                "4XX",
                "500",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "201", "application/json"):
            return unmarshal_json_response(
                models.PostByOrgByRepoWebhooksResponse, http_res
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgByRepoWebhooksBadRequestErrorData, http_res
            )
            raise errors.PostByOrgByRepoWebhooksBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgByRepoWebhooksUnauthorizedErrorData, http_res
            )
            raise errors.PostByOrgByRepoWebhooksUnauthorizedError(
                response_data, http_res
            )
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgByRepoWebhooksForbiddenErrorData, http_res
            )
            raise errors.PostByOrgByRepoWebhooksForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgByRepoWebhooksNotFoundErrorData, http_res
            )
            raise errors.PostByOrgByRepoWebhooksNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "406", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgByRepoWebhooksNotAcceptableErrorData, http_res
            )
            raise errors.PostByOrgByRepoWebhooksNotAcceptableError(
                response_data, http_res
            )
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgByRepoWebhooksConflictErrorData, http_res
            )
            raise errors.PostByOrgByRepoWebhooksConflictError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgByRepoWebhooksInternalServerErrorData, http_res
            )
            raise errors.PostByOrgByRepoWebhooksInternalServerError(
                response_data, http_res
            )
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)

        raise errors.MesaDefaultError("Unexpected response received", http_res)

    def delete(
        self,
        *,
        org: str,
        repo: str,
        webhook_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.DeleteByOrgByRepoWebhooksByWebhookIDResponse:
        r"""Delete webhook

        Delete a webhook from a repository

        :param org:
        :param repo:
        :param webhook_id:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.DeleteByOrgByRepoWebhooksByWebhookIDRequest(
            org=org,
            repo=repo,
            webhook_id=webhook_id,
        )

        req = self._build_request(
            method="DELETE",
            path="/{org}/{repo}/webhooks/{webhookId}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="deleteByOrgByRepoWebhooksByWebhookId",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "406",
                "409",
                "4XX",
                "500",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.DeleteByOrgByRepoWebhooksByWebhookIDResponse, http_res
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgByRepoWebhooksByWebhookIDBadRequestErrorData, http_res
            )
            raise errors.DeleteByOrgByRepoWebhooksByWebhookIDBadRequestError(
                response_data, http_res
            )
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgByRepoWebhooksByWebhookIDUnauthorizedErrorData,
                http_res,
            )
            raise errors.DeleteByOrgByRepoWebhooksByWebhookIDUnauthorizedError(
                response_data, http_res
            )
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgByRepoWebhooksByWebhookIDForbiddenErrorData, http_res
            )
            raise errors.DeleteByOrgByRepoWebhooksByWebhookIDForbiddenError(
                response_data, http_res
            )
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgByRepoWebhooksByWebhookIDNotFoundErrorData, http_res
            )
            raise errors.DeleteByOrgByRepoWebhooksByWebhookIDNotFoundError(
                response_data, http_res
            )
        if utils.match_response(http_res, "406", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgByRepoWebhooksByWebhookIDNotAcceptableErrorData,
                http_res,
            )
            raise errors.DeleteByOrgByRepoWebhooksByWebhookIDNotAcceptableError(
                response_data, http_res
            )
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgByRepoWebhooksByWebhookIDConflictErrorData, http_res
            )
            raise errors.DeleteByOrgByRepoWebhooksByWebhookIDConflictError(
                response_data, http_res
            )
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgByRepoWebhooksByWebhookIDInternalServerErrorData,
                http_res,
            )
            raise errors.DeleteByOrgByRepoWebhooksByWebhookIDInternalServerError(
                response_data, http_res
            )
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)

        raise errors.MesaDefaultError("Unexpected response received", http_res)

    async def delete_async(
        self,
        *,
        org: str,
        repo: str,
        webhook_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.DeleteByOrgByRepoWebhooksByWebhookIDResponse:
        r"""Delete webhook

        Delete a webhook from a repository

        :param org:
        :param repo:
        :param webhook_id:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.DeleteByOrgByRepoWebhooksByWebhookIDRequest(
            org=org,
            repo=repo,
            webhook_id=webhook_id,
        )

        req = self._build_request_async(
            method="DELETE",
            path="/{org}/{repo}/webhooks/{webhookId}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="deleteByOrgByRepoWebhooksByWebhookId",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "406",
                "409",
                "4XX",
                "500",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.DeleteByOrgByRepoWebhooksByWebhookIDResponse, http_res
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgByRepoWebhooksByWebhookIDBadRequestErrorData, http_res
            )
            raise errors.DeleteByOrgByRepoWebhooksByWebhookIDBadRequestError(
                response_data, http_res
            )
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgByRepoWebhooksByWebhookIDUnauthorizedErrorData,
                http_res,
            )
            raise errors.DeleteByOrgByRepoWebhooksByWebhookIDUnauthorizedError(
                response_data, http_res
            )
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgByRepoWebhooksByWebhookIDForbiddenErrorData, http_res
            )
            raise errors.DeleteByOrgByRepoWebhooksByWebhookIDForbiddenError(
                response_data, http_res
            )
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgByRepoWebhooksByWebhookIDNotFoundErrorData, http_res
            )
            raise errors.DeleteByOrgByRepoWebhooksByWebhookIDNotFoundError(
                response_data, http_res
            )
        if utils.match_response(http_res, "406", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgByRepoWebhooksByWebhookIDNotAcceptableErrorData,
                http_res,
            )
            raise errors.DeleteByOrgByRepoWebhooksByWebhookIDNotAcceptableError(
                response_data, http_res
            )
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgByRepoWebhooksByWebhookIDConflictErrorData, http_res
            )
            raise errors.DeleteByOrgByRepoWebhooksByWebhookIDConflictError(
                response_data, http_res
            )
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgByRepoWebhooksByWebhookIDInternalServerErrorData,
                http_res,
            )
            raise errors.DeleteByOrgByRepoWebhooksByWebhookIDInternalServerError(
                response_data, http_res
            )
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)

        raise errors.MesaDefaultError("Unexpected response received", http_res)
