"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .mesaerror import MesaError
from typing import TYPE_CHECKING
from importlib import import_module
import builtins
import sys

if TYPE_CHECKING:
    from .deletebyorgapikeysbyidop import (
        DeleteByOrgAPIKeysByIDBadRequestError,
        DeleteByOrgAPIKeysByIDBadRequestErrorData,
        DeleteByOrgAPIKeysByIDConflictError,
        DeleteByOrgAPIKeysByIDConflictErrorData,
        DeleteByOrgAPIKeysByIDForbiddenError,
        DeleteByOrgAPIKeysByIDForbiddenErrorData,
        DeleteByOrgAPIKeysByIDInternalServerError,
        DeleteByOrgAPIKeysByIDInternalServerErrorData,
        DeleteByOrgAPIKeysByIDNotAcceptableError,
        DeleteByOrgAPIKeysByIDNotAcceptableErrorData,
        DeleteByOrgAPIKeysByIDNotFoundError,
        DeleteByOrgAPIKeysByIDNotFoundErrorData,
        DeleteByOrgAPIKeysByIDUnauthorizedError,
        DeleteByOrgAPIKeysByIDUnauthorizedErrorData,
    )
    from .deletebyorgbyrepobranchesbybranchop import (
        DeleteByOrgByRepoBranchesByBranchBadRequestError,
        DeleteByOrgByRepoBranchesByBranchBadRequestErrorData,
        DeleteByOrgByRepoBranchesByBranchConflictError,
        DeleteByOrgByRepoBranchesByBranchConflictErrorData,
        DeleteByOrgByRepoBranchesByBranchForbiddenError,
        DeleteByOrgByRepoBranchesByBranchForbiddenErrorData,
        DeleteByOrgByRepoBranchesByBranchInternalServerError,
        DeleteByOrgByRepoBranchesByBranchInternalServerErrorData,
        DeleteByOrgByRepoBranchesByBranchNotAcceptableError,
        DeleteByOrgByRepoBranchesByBranchNotAcceptableErrorData,
        DeleteByOrgByRepoBranchesByBranchNotFoundError,
        DeleteByOrgByRepoBranchesByBranchNotFoundErrorData,
        DeleteByOrgByRepoBranchesByBranchUnauthorizedError,
        DeleteByOrgByRepoBranchesByBranchUnauthorizedErrorData,
    )
    from .deletebyorgbyrepoop import (
        DeleteByOrgByRepoBadRequestError,
        DeleteByOrgByRepoBadRequestErrorData,
        DeleteByOrgByRepoConflictError,
        DeleteByOrgByRepoConflictErrorData,
        DeleteByOrgByRepoForbiddenError,
        DeleteByOrgByRepoForbiddenErrorData,
        DeleteByOrgByRepoInternalServerError,
        DeleteByOrgByRepoInternalServerErrorData,
        DeleteByOrgByRepoNotAcceptableError,
        DeleteByOrgByRepoNotAcceptableErrorData,
        DeleteByOrgByRepoNotFoundError,
        DeleteByOrgByRepoNotFoundErrorData,
        DeleteByOrgByRepoUnauthorizedError,
        DeleteByOrgByRepoUnauthorizedErrorData,
    )
    from .deletebyorgbyrepowebhooksbywebhookidop import (
        DeleteByOrgByRepoWebhooksByWebhookIDBadRequestError,
        DeleteByOrgByRepoWebhooksByWebhookIDBadRequestErrorData,
        DeleteByOrgByRepoWebhooksByWebhookIDConflictError,
        DeleteByOrgByRepoWebhooksByWebhookIDConflictErrorData,
        DeleteByOrgByRepoWebhooksByWebhookIDForbiddenError,
        DeleteByOrgByRepoWebhooksByWebhookIDForbiddenErrorData,
        DeleteByOrgByRepoWebhooksByWebhookIDInternalServerError,
        DeleteByOrgByRepoWebhooksByWebhookIDInternalServerErrorData,
        DeleteByOrgByRepoWebhooksByWebhookIDNotAcceptableError,
        DeleteByOrgByRepoWebhooksByWebhookIDNotAcceptableErrorData,
        DeleteByOrgByRepoWebhooksByWebhookIDNotFoundError,
        DeleteByOrgByRepoWebhooksByWebhookIDNotFoundErrorData,
        DeleteByOrgByRepoWebhooksByWebhookIDUnauthorizedError,
        DeleteByOrgByRepoWebhooksByWebhookIDUnauthorizedErrorData,
    )
    from .getbyorgapikeysop import (
        GetByOrgAPIKeysBadRequestError,
        GetByOrgAPIKeysBadRequestErrorData,
        GetByOrgAPIKeysConflictError,
        GetByOrgAPIKeysConflictErrorData,
        GetByOrgAPIKeysForbiddenError,
        GetByOrgAPIKeysForbiddenErrorData,
        GetByOrgAPIKeysInternalServerError,
        GetByOrgAPIKeysInternalServerErrorData,
        GetByOrgAPIKeysNotAcceptableError,
        GetByOrgAPIKeysNotAcceptableErrorData,
        GetByOrgAPIKeysNotFoundError,
        GetByOrgAPIKeysNotFoundErrorData,
        GetByOrgAPIKeysUnauthorizedError,
        GetByOrgAPIKeysUnauthorizedErrorData,
    )
    from .getbyorgbyrepoagentblameop import (
        GetByOrgByRepoAgentblameBadRequestError,
        GetByOrgByRepoAgentblameBadRequestErrorData,
        GetByOrgByRepoAgentblameConflictError,
        GetByOrgByRepoAgentblameConflictErrorData,
        GetByOrgByRepoAgentblameForbiddenError,
        GetByOrgByRepoAgentblameForbiddenErrorData,
        GetByOrgByRepoAgentblameInternalServerError,
        GetByOrgByRepoAgentblameInternalServerErrorData,
        GetByOrgByRepoAgentblameNotAcceptableError,
        GetByOrgByRepoAgentblameNotAcceptableErrorData,
        GetByOrgByRepoAgentblameNotFoundError,
        GetByOrgByRepoAgentblameNotFoundErrorData,
        GetByOrgByRepoAgentblameUnauthorizedError,
        GetByOrgByRepoAgentblameUnauthorizedErrorData,
    )
    from .getbyorgbyrepoanalyticsop import (
        GetByOrgByRepoAnalyticsBadRequestError,
        GetByOrgByRepoAnalyticsBadRequestErrorData,
        GetByOrgByRepoAnalyticsConflictError,
        GetByOrgByRepoAnalyticsConflictErrorData,
        GetByOrgByRepoAnalyticsForbiddenError,
        GetByOrgByRepoAnalyticsForbiddenErrorData,
        GetByOrgByRepoAnalyticsInternalServerError,
        GetByOrgByRepoAnalyticsInternalServerErrorData,
        GetByOrgByRepoAnalyticsNotAcceptableError,
        GetByOrgByRepoAnalyticsNotAcceptableErrorData,
        GetByOrgByRepoAnalyticsNotFoundError,
        GetByOrgByRepoAnalyticsNotFoundErrorData,
        GetByOrgByRepoAnalyticsUnauthorizedError,
        GetByOrgByRepoAnalyticsUnauthorizedErrorData,
    )
    from .getbyorgbyrepobranchesop import (
        GetByOrgByRepoBranchesBadRequestError,
        GetByOrgByRepoBranchesBadRequestErrorData,
        GetByOrgByRepoBranchesConflictError,
        GetByOrgByRepoBranchesConflictErrorData,
        GetByOrgByRepoBranchesForbiddenError,
        GetByOrgByRepoBranchesForbiddenErrorData,
        GetByOrgByRepoBranchesInternalServerError,
        GetByOrgByRepoBranchesInternalServerErrorData,
        GetByOrgByRepoBranchesNotAcceptableError,
        GetByOrgByRepoBranchesNotAcceptableErrorData,
        GetByOrgByRepoBranchesNotFoundError,
        GetByOrgByRepoBranchesNotFoundErrorData,
        GetByOrgByRepoBranchesUnauthorizedError,
        GetByOrgByRepoBranchesUnauthorizedErrorData,
    )
    from .getbyorgbyrepocommitsbyshaop import (
        GetByOrgByRepoCommitsByShaBadRequestError,
        GetByOrgByRepoCommitsByShaBadRequestErrorData,
        GetByOrgByRepoCommitsByShaConflictError,
        GetByOrgByRepoCommitsByShaConflictErrorData,
        GetByOrgByRepoCommitsByShaForbiddenError,
        GetByOrgByRepoCommitsByShaForbiddenErrorData,
        GetByOrgByRepoCommitsByShaInternalServerError,
        GetByOrgByRepoCommitsByShaInternalServerErrorData,
        GetByOrgByRepoCommitsByShaNotAcceptableError,
        GetByOrgByRepoCommitsByShaNotAcceptableErrorData,
        GetByOrgByRepoCommitsByShaNotFoundError,
        GetByOrgByRepoCommitsByShaNotFoundErrorData,
        GetByOrgByRepoCommitsByShaUnauthorizedError,
        GetByOrgByRepoCommitsByShaUnauthorizedErrorData,
    )
    from .getbyorgbyrepocommitsop import (
        GetByOrgByRepoCommitsBadRequestError,
        GetByOrgByRepoCommitsBadRequestErrorData,
        GetByOrgByRepoCommitsConflictError,
        GetByOrgByRepoCommitsConflictErrorData,
        GetByOrgByRepoCommitsForbiddenError,
        GetByOrgByRepoCommitsForbiddenErrorData,
        GetByOrgByRepoCommitsInternalServerError,
        GetByOrgByRepoCommitsInternalServerErrorData,
        GetByOrgByRepoCommitsNotAcceptableError,
        GetByOrgByRepoCommitsNotAcceptableErrorData,
        GetByOrgByRepoCommitsNotFoundError,
        GetByOrgByRepoCommitsNotFoundErrorData,
        GetByOrgByRepoCommitsUnauthorizedError,
        GetByOrgByRepoCommitsUnauthorizedErrorData,
    )
    from .getbyorgbyrepocontentop import (
        GetByOrgByRepoContentBadRequestError,
        GetByOrgByRepoContentBadRequestErrorData,
        GetByOrgByRepoContentConflictError,
        GetByOrgByRepoContentConflictErrorData,
        GetByOrgByRepoContentForbiddenError,
        GetByOrgByRepoContentForbiddenErrorData,
        GetByOrgByRepoContentInternalServerError,
        GetByOrgByRepoContentInternalServerErrorData,
        GetByOrgByRepoContentNotAcceptableError,
        GetByOrgByRepoContentNotAcceptableErrorData,
        GetByOrgByRepoContentNotFoundError,
        GetByOrgByRepoContentNotFoundErrorData,
        GetByOrgByRepoContentUnauthorizedError,
        GetByOrgByRepoContentUnauthorizedErrorData,
    )
    from .getbyorgbyrepodiffop import (
        GetByOrgByRepoDiffBadRequestError,
        GetByOrgByRepoDiffBadRequestErrorData,
        GetByOrgByRepoDiffConflictError,
        GetByOrgByRepoDiffConflictErrorData,
        GetByOrgByRepoDiffForbiddenError,
        GetByOrgByRepoDiffForbiddenErrorData,
        GetByOrgByRepoDiffInternalServerError,
        GetByOrgByRepoDiffInternalServerErrorData,
        GetByOrgByRepoDiffNotAcceptableError,
        GetByOrgByRepoDiffNotAcceptableErrorData,
        GetByOrgByRepoDiffNotFoundError,
        GetByOrgByRepoDiffNotFoundErrorData,
        GetByOrgByRepoDiffUnauthorizedError,
        GetByOrgByRepoDiffUnauthorizedErrorData,
    )
    from .getbyorgbyrepoop import (
        GetByOrgByRepoBadRequestError,
        GetByOrgByRepoBadRequestErrorData,
        GetByOrgByRepoConflictError,
        GetByOrgByRepoConflictErrorData,
        GetByOrgByRepoForbiddenError,
        GetByOrgByRepoForbiddenErrorData,
        GetByOrgByRepoInternalServerError,
        GetByOrgByRepoInternalServerErrorData,
        GetByOrgByRepoNotAcceptableError,
        GetByOrgByRepoNotAcceptableErrorData,
        GetByOrgByRepoNotFoundError,
        GetByOrgByRepoNotFoundErrorData,
        GetByOrgByRepoUnauthorizedError,
        GetByOrgByRepoUnauthorizedErrorData,
    )
    from .getbyorgbyreposyncop import (
        GetByOrgByRepoSyncBadRequestError,
        GetByOrgByRepoSyncBadRequestErrorData,
        GetByOrgByRepoSyncConflictError,
        GetByOrgByRepoSyncConflictErrorData,
        GetByOrgByRepoSyncForbiddenError,
        GetByOrgByRepoSyncForbiddenErrorData,
        GetByOrgByRepoSyncInternalServerError,
        GetByOrgByRepoSyncInternalServerErrorData,
        GetByOrgByRepoSyncNotAcceptableError,
        GetByOrgByRepoSyncNotAcceptableErrorData,
        GetByOrgByRepoSyncNotFoundError,
        GetByOrgByRepoSyncNotFoundErrorData,
        GetByOrgByRepoSyncUnauthorizedError,
        GetByOrgByRepoSyncUnauthorizedErrorData,
    )
    from .getbyorgbyrepowebhooksop import (
        GetByOrgByRepoWebhooksBadRequestError,
        GetByOrgByRepoWebhooksBadRequestErrorData,
        GetByOrgByRepoWebhooksConflictError,
        GetByOrgByRepoWebhooksConflictErrorData,
        GetByOrgByRepoWebhooksForbiddenError,
        GetByOrgByRepoWebhooksForbiddenErrorData,
        GetByOrgByRepoWebhooksInternalServerError,
        GetByOrgByRepoWebhooksInternalServerErrorData,
        GetByOrgByRepoWebhooksNotAcceptableError,
        GetByOrgByRepoWebhooksNotAcceptableErrorData,
        GetByOrgByRepoWebhooksNotFoundError,
        GetByOrgByRepoWebhooksNotFoundErrorData,
        GetByOrgByRepoWebhooksUnauthorizedError,
        GetByOrgByRepoWebhooksUnauthorizedErrorData,
    )
    from .getbyorgop import (
        GetByOrgBadRequestError,
        GetByOrgBadRequestErrorData,
        GetByOrgConflictError,
        GetByOrgConflictErrorData,
        GetByOrgForbiddenError,
        GetByOrgForbiddenErrorData,
        GetByOrgInternalServerError,
        GetByOrgInternalServerErrorData,
        GetByOrgNotAcceptableError,
        GetByOrgNotAcceptableErrorData,
        GetByOrgNotFoundError,
        GetByOrgNotFoundErrorData,
        GetByOrgUnauthorizedError,
        GetByOrgUnauthorizedErrorData,
    )
    from .getbyorgreposop import (
        GetByOrgReposBadRequestError,
        GetByOrgReposBadRequestErrorData,
        GetByOrgReposConflictError,
        GetByOrgReposConflictErrorData,
        GetByOrgReposForbiddenError,
        GetByOrgReposForbiddenErrorData,
        GetByOrgReposInternalServerError,
        GetByOrgReposInternalServerErrorData,
        GetByOrgReposNotAcceptableError,
        GetByOrgReposNotAcceptableErrorData,
        GetByOrgReposNotFoundError,
        GetByOrgReposNotFoundErrorData,
        GetByOrgReposUnauthorizedError,
        GetByOrgReposUnauthorizedErrorData,
    )
    from .mesadefaulterror import MesaDefaultError
    from .no_response_error import NoResponseError
    from .patchbyorgbyrepoop import (
        PatchByOrgByRepoBadRequestError,
        PatchByOrgByRepoBadRequestErrorData,
        PatchByOrgByRepoConflictError,
        PatchByOrgByRepoConflictErrorData,
        PatchByOrgByRepoForbiddenError,
        PatchByOrgByRepoForbiddenErrorData,
        PatchByOrgByRepoInternalServerError,
        PatchByOrgByRepoInternalServerErrorData,
        PatchByOrgByRepoNotAcceptableError,
        PatchByOrgByRepoNotAcceptableErrorData,
        PatchByOrgByRepoNotFoundError,
        PatchByOrgByRepoNotFoundErrorData,
        PatchByOrgByRepoUnauthorizedError,
        PatchByOrgByRepoUnauthorizedErrorData,
    )
    from .postbyorgapikeysop import (
        PostByOrgAPIKeysBadRequestError,
        PostByOrgAPIKeysBadRequestErrorData,
        PostByOrgAPIKeysConflictError,
        PostByOrgAPIKeysConflictErrorData,
        PostByOrgAPIKeysForbiddenError,
        PostByOrgAPIKeysForbiddenErrorData,
        PostByOrgAPIKeysInternalServerError,
        PostByOrgAPIKeysInternalServerErrorData,
        PostByOrgAPIKeysNotAcceptableError,
        PostByOrgAPIKeysNotAcceptableErrorData,
        PostByOrgAPIKeysNotFoundError,
        PostByOrgAPIKeysNotFoundErrorData,
        PostByOrgAPIKeysUnauthorizedError,
        PostByOrgAPIKeysUnauthorizedErrorData,
    )
    from .postbyorgbyrepoanalyticsrefreshop import (
        PostByOrgByRepoAnalyticsRefreshBadRequestError,
        PostByOrgByRepoAnalyticsRefreshBadRequestErrorData,
        PostByOrgByRepoAnalyticsRefreshConflictError,
        PostByOrgByRepoAnalyticsRefreshConflictErrorData,
        PostByOrgByRepoAnalyticsRefreshForbiddenError,
        PostByOrgByRepoAnalyticsRefreshForbiddenErrorData,
        PostByOrgByRepoAnalyticsRefreshInternalServerError,
        PostByOrgByRepoAnalyticsRefreshInternalServerErrorData,
        PostByOrgByRepoAnalyticsRefreshNotAcceptableError,
        PostByOrgByRepoAnalyticsRefreshNotAcceptableErrorData,
        PostByOrgByRepoAnalyticsRefreshNotFoundError,
        PostByOrgByRepoAnalyticsRefreshNotFoundErrorData,
        PostByOrgByRepoAnalyticsRefreshUnauthorizedError,
        PostByOrgByRepoAnalyticsRefreshUnauthorizedErrorData,
    )
    from .postbyorgbyrepobranchesop import (
        PostByOrgByRepoBranchesBadRequestError,
        PostByOrgByRepoBranchesBadRequestErrorData,
        PostByOrgByRepoBranchesConflictError,
        PostByOrgByRepoBranchesConflictErrorData,
        PostByOrgByRepoBranchesForbiddenError,
        PostByOrgByRepoBranchesForbiddenErrorData,
        PostByOrgByRepoBranchesInternalServerError,
        PostByOrgByRepoBranchesInternalServerErrorData,
        PostByOrgByRepoBranchesNotAcceptableError,
        PostByOrgByRepoBranchesNotAcceptableErrorData,
        PostByOrgByRepoBranchesNotFoundError,
        PostByOrgByRepoBranchesNotFoundErrorData,
        PostByOrgByRepoBranchesUnauthorizedError,
        PostByOrgByRepoBranchesUnauthorizedErrorData,
    )
    from .postbyorgbyrepocommitsop import (
        PostByOrgByRepoCommitsBadRequestError,
        PostByOrgByRepoCommitsBadRequestErrorData,
        PostByOrgByRepoCommitsConflictError,
        PostByOrgByRepoCommitsConflictErrorData,
        PostByOrgByRepoCommitsForbiddenError,
        PostByOrgByRepoCommitsForbiddenErrorData,
        PostByOrgByRepoCommitsInternalServerError,
        PostByOrgByRepoCommitsInternalServerErrorData,
        PostByOrgByRepoCommitsNotAcceptableError,
        PostByOrgByRepoCommitsNotAcceptableErrorData,
        PostByOrgByRepoCommitsNotFoundError,
        PostByOrgByRepoCommitsNotFoundErrorData,
        PostByOrgByRepoCommitsUnauthorizedError,
        PostByOrgByRepoCommitsUnauthorizedErrorData,
    )
    from .postbyorgbyreposyncop import (
        PostByOrgByRepoSyncBadRequestError,
        PostByOrgByRepoSyncBadRequestErrorData,
        PostByOrgByRepoSyncConflictError,
        PostByOrgByRepoSyncConflictErrorData,
        PostByOrgByRepoSyncForbiddenError,
        PostByOrgByRepoSyncForbiddenErrorData,
        PostByOrgByRepoSyncInternalServerError,
        PostByOrgByRepoSyncInternalServerErrorData,
        PostByOrgByRepoSyncNotAcceptableError,
        PostByOrgByRepoSyncNotAcceptableErrorData,
        PostByOrgByRepoSyncNotFoundError,
        PostByOrgByRepoSyncNotFoundErrorData,
        PostByOrgByRepoSyncUnauthorizedError,
        PostByOrgByRepoSyncUnauthorizedErrorData,
    )
    from .postbyorgbyrepowebhooksop import (
        PostByOrgByRepoWebhooksBadRequestError,
        PostByOrgByRepoWebhooksBadRequestErrorData,
        PostByOrgByRepoWebhooksConflictError,
        PostByOrgByRepoWebhooksConflictErrorData,
        PostByOrgByRepoWebhooksForbiddenError,
        PostByOrgByRepoWebhooksForbiddenErrorData,
        PostByOrgByRepoWebhooksInternalServerError,
        PostByOrgByRepoWebhooksInternalServerErrorData,
        PostByOrgByRepoWebhooksNotAcceptableError,
        PostByOrgByRepoWebhooksNotAcceptableErrorData,
        PostByOrgByRepoWebhooksNotFoundError,
        PostByOrgByRepoWebhooksNotFoundErrorData,
        PostByOrgByRepoWebhooksUnauthorizedError,
        PostByOrgByRepoWebhooksUnauthorizedErrorData,
    )
    from .postbyorgreposop import (
        PostByOrgReposBadRequestError,
        PostByOrgReposBadRequestErrorData,
        PostByOrgReposConflictError,
        PostByOrgReposConflictErrorData,
        PostByOrgReposForbiddenError,
        PostByOrgReposForbiddenErrorData,
        PostByOrgReposInternalServerError,
        PostByOrgReposInternalServerErrorData,
        PostByOrgReposNotAcceptableError,
        PostByOrgReposNotAcceptableErrorData,
        PostByOrgReposNotFoundError,
        PostByOrgReposNotFoundErrorData,
        PostByOrgReposUnauthorizedError,
        PostByOrgReposUnauthorizedErrorData,
    )
    from .responsevalidationerror import ResponseValidationError

__all__ = [
    "DeleteByOrgAPIKeysByIDBadRequestError",
    "DeleteByOrgAPIKeysByIDBadRequestErrorData",
    "DeleteByOrgAPIKeysByIDConflictError",
    "DeleteByOrgAPIKeysByIDConflictErrorData",
    "DeleteByOrgAPIKeysByIDForbiddenError",
    "DeleteByOrgAPIKeysByIDForbiddenErrorData",
    "DeleteByOrgAPIKeysByIDInternalServerError",
    "DeleteByOrgAPIKeysByIDInternalServerErrorData",
    "DeleteByOrgAPIKeysByIDNotAcceptableError",
    "DeleteByOrgAPIKeysByIDNotAcceptableErrorData",
    "DeleteByOrgAPIKeysByIDNotFoundError",
    "DeleteByOrgAPIKeysByIDNotFoundErrorData",
    "DeleteByOrgAPIKeysByIDUnauthorizedError",
    "DeleteByOrgAPIKeysByIDUnauthorizedErrorData",
    "DeleteByOrgByRepoBadRequestError",
    "DeleteByOrgByRepoBadRequestErrorData",
    "DeleteByOrgByRepoBranchesByBranchBadRequestError",
    "DeleteByOrgByRepoBranchesByBranchBadRequestErrorData",
    "DeleteByOrgByRepoBranchesByBranchConflictError",
    "DeleteByOrgByRepoBranchesByBranchConflictErrorData",
    "DeleteByOrgByRepoBranchesByBranchForbiddenError",
    "DeleteByOrgByRepoBranchesByBranchForbiddenErrorData",
    "DeleteByOrgByRepoBranchesByBranchInternalServerError",
    "DeleteByOrgByRepoBranchesByBranchInternalServerErrorData",
    "DeleteByOrgByRepoBranchesByBranchNotAcceptableError",
    "DeleteByOrgByRepoBranchesByBranchNotAcceptableErrorData",
    "DeleteByOrgByRepoBranchesByBranchNotFoundError",
    "DeleteByOrgByRepoBranchesByBranchNotFoundErrorData",
    "DeleteByOrgByRepoBranchesByBranchUnauthorizedError",
    "DeleteByOrgByRepoBranchesByBranchUnauthorizedErrorData",
    "DeleteByOrgByRepoConflictError",
    "DeleteByOrgByRepoConflictErrorData",
    "DeleteByOrgByRepoForbiddenError",
    "DeleteByOrgByRepoForbiddenErrorData",
    "DeleteByOrgByRepoInternalServerError",
    "DeleteByOrgByRepoInternalServerErrorData",
    "DeleteByOrgByRepoNotAcceptableError",
    "DeleteByOrgByRepoNotAcceptableErrorData",
    "DeleteByOrgByRepoNotFoundError",
    "DeleteByOrgByRepoNotFoundErrorData",
    "DeleteByOrgByRepoUnauthorizedError",
    "DeleteByOrgByRepoUnauthorizedErrorData",
    "DeleteByOrgByRepoWebhooksByWebhookIDBadRequestError",
    "DeleteByOrgByRepoWebhooksByWebhookIDBadRequestErrorData",
    "DeleteByOrgByRepoWebhooksByWebhookIDConflictError",
    "DeleteByOrgByRepoWebhooksByWebhookIDConflictErrorData",
    "DeleteByOrgByRepoWebhooksByWebhookIDForbiddenError",
    "DeleteByOrgByRepoWebhooksByWebhookIDForbiddenErrorData",
    "DeleteByOrgByRepoWebhooksByWebhookIDInternalServerError",
    "DeleteByOrgByRepoWebhooksByWebhookIDInternalServerErrorData",
    "DeleteByOrgByRepoWebhooksByWebhookIDNotAcceptableError",
    "DeleteByOrgByRepoWebhooksByWebhookIDNotAcceptableErrorData",
    "DeleteByOrgByRepoWebhooksByWebhookIDNotFoundError",
    "DeleteByOrgByRepoWebhooksByWebhookIDNotFoundErrorData",
    "DeleteByOrgByRepoWebhooksByWebhookIDUnauthorizedError",
    "DeleteByOrgByRepoWebhooksByWebhookIDUnauthorizedErrorData",
    "GetByOrgAPIKeysBadRequestError",
    "GetByOrgAPIKeysBadRequestErrorData",
    "GetByOrgAPIKeysConflictError",
    "GetByOrgAPIKeysConflictErrorData",
    "GetByOrgAPIKeysForbiddenError",
    "GetByOrgAPIKeysForbiddenErrorData",
    "GetByOrgAPIKeysInternalServerError",
    "GetByOrgAPIKeysInternalServerErrorData",
    "GetByOrgAPIKeysNotAcceptableError",
    "GetByOrgAPIKeysNotAcceptableErrorData",
    "GetByOrgAPIKeysNotFoundError",
    "GetByOrgAPIKeysNotFoundErrorData",
    "GetByOrgAPIKeysUnauthorizedError",
    "GetByOrgAPIKeysUnauthorizedErrorData",
    "GetByOrgBadRequestError",
    "GetByOrgBadRequestErrorData",
    "GetByOrgByRepoAgentblameBadRequestError",
    "GetByOrgByRepoAgentblameBadRequestErrorData",
    "GetByOrgByRepoAgentblameConflictError",
    "GetByOrgByRepoAgentblameConflictErrorData",
    "GetByOrgByRepoAgentblameForbiddenError",
    "GetByOrgByRepoAgentblameForbiddenErrorData",
    "GetByOrgByRepoAgentblameInternalServerError",
    "GetByOrgByRepoAgentblameInternalServerErrorData",
    "GetByOrgByRepoAgentblameNotAcceptableError",
    "GetByOrgByRepoAgentblameNotAcceptableErrorData",
    "GetByOrgByRepoAgentblameNotFoundError",
    "GetByOrgByRepoAgentblameNotFoundErrorData",
    "GetByOrgByRepoAgentblameUnauthorizedError",
    "GetByOrgByRepoAgentblameUnauthorizedErrorData",
    "GetByOrgByRepoAnalyticsBadRequestError",
    "GetByOrgByRepoAnalyticsBadRequestErrorData",
    "GetByOrgByRepoAnalyticsConflictError",
    "GetByOrgByRepoAnalyticsConflictErrorData",
    "GetByOrgByRepoAnalyticsForbiddenError",
    "GetByOrgByRepoAnalyticsForbiddenErrorData",
    "GetByOrgByRepoAnalyticsInternalServerError",
    "GetByOrgByRepoAnalyticsInternalServerErrorData",
    "GetByOrgByRepoAnalyticsNotAcceptableError",
    "GetByOrgByRepoAnalyticsNotAcceptableErrorData",
    "GetByOrgByRepoAnalyticsNotFoundError",
    "GetByOrgByRepoAnalyticsNotFoundErrorData",
    "GetByOrgByRepoAnalyticsUnauthorizedError",
    "GetByOrgByRepoAnalyticsUnauthorizedErrorData",
    "GetByOrgByRepoBadRequestError",
    "GetByOrgByRepoBadRequestErrorData",
    "GetByOrgByRepoBranchesBadRequestError",
    "GetByOrgByRepoBranchesBadRequestErrorData",
    "GetByOrgByRepoBranchesConflictError",
    "GetByOrgByRepoBranchesConflictErrorData",
    "GetByOrgByRepoBranchesForbiddenError",
    "GetByOrgByRepoBranchesForbiddenErrorData",
    "GetByOrgByRepoBranchesInternalServerError",
    "GetByOrgByRepoBranchesInternalServerErrorData",
    "GetByOrgByRepoBranchesNotAcceptableError",
    "GetByOrgByRepoBranchesNotAcceptableErrorData",
    "GetByOrgByRepoBranchesNotFoundError",
    "GetByOrgByRepoBranchesNotFoundErrorData",
    "GetByOrgByRepoBranchesUnauthorizedError",
    "GetByOrgByRepoBranchesUnauthorizedErrorData",
    "GetByOrgByRepoCommitsBadRequestError",
    "GetByOrgByRepoCommitsBadRequestErrorData",
    "GetByOrgByRepoCommitsByShaBadRequestError",
    "GetByOrgByRepoCommitsByShaBadRequestErrorData",
    "GetByOrgByRepoCommitsByShaConflictError",
    "GetByOrgByRepoCommitsByShaConflictErrorData",
    "GetByOrgByRepoCommitsByShaForbiddenError",
    "GetByOrgByRepoCommitsByShaForbiddenErrorData",
    "GetByOrgByRepoCommitsByShaInternalServerError",
    "GetByOrgByRepoCommitsByShaInternalServerErrorData",
    "GetByOrgByRepoCommitsByShaNotAcceptableError",
    "GetByOrgByRepoCommitsByShaNotAcceptableErrorData",
    "GetByOrgByRepoCommitsByShaNotFoundError",
    "GetByOrgByRepoCommitsByShaNotFoundErrorData",
    "GetByOrgByRepoCommitsByShaUnauthorizedError",
    "GetByOrgByRepoCommitsByShaUnauthorizedErrorData",
    "GetByOrgByRepoCommitsConflictError",
    "GetByOrgByRepoCommitsConflictErrorData",
    "GetByOrgByRepoCommitsForbiddenError",
    "GetByOrgByRepoCommitsForbiddenErrorData",
    "GetByOrgByRepoCommitsInternalServerError",
    "GetByOrgByRepoCommitsInternalServerErrorData",
    "GetByOrgByRepoCommitsNotAcceptableError",
    "GetByOrgByRepoCommitsNotAcceptableErrorData",
    "GetByOrgByRepoCommitsNotFoundError",
    "GetByOrgByRepoCommitsNotFoundErrorData",
    "GetByOrgByRepoCommitsUnauthorizedError",
    "GetByOrgByRepoCommitsUnauthorizedErrorData",
    "GetByOrgByRepoConflictError",
    "GetByOrgByRepoConflictErrorData",
    "GetByOrgByRepoContentBadRequestError",
    "GetByOrgByRepoContentBadRequestErrorData",
    "GetByOrgByRepoContentConflictError",
    "GetByOrgByRepoContentConflictErrorData",
    "GetByOrgByRepoContentForbiddenError",
    "GetByOrgByRepoContentForbiddenErrorData",
    "GetByOrgByRepoContentInternalServerError",
    "GetByOrgByRepoContentInternalServerErrorData",
    "GetByOrgByRepoContentNotAcceptableError",
    "GetByOrgByRepoContentNotAcceptableErrorData",
    "GetByOrgByRepoContentNotFoundError",
    "GetByOrgByRepoContentNotFoundErrorData",
    "GetByOrgByRepoContentUnauthorizedError",
    "GetByOrgByRepoContentUnauthorizedErrorData",
    "GetByOrgByRepoDiffBadRequestError",
    "GetByOrgByRepoDiffBadRequestErrorData",
    "GetByOrgByRepoDiffConflictError",
    "GetByOrgByRepoDiffConflictErrorData",
    "GetByOrgByRepoDiffForbiddenError",
    "GetByOrgByRepoDiffForbiddenErrorData",
    "GetByOrgByRepoDiffInternalServerError",
    "GetByOrgByRepoDiffInternalServerErrorData",
    "GetByOrgByRepoDiffNotAcceptableError",
    "GetByOrgByRepoDiffNotAcceptableErrorData",
    "GetByOrgByRepoDiffNotFoundError",
    "GetByOrgByRepoDiffNotFoundErrorData",
    "GetByOrgByRepoDiffUnauthorizedError",
    "GetByOrgByRepoDiffUnauthorizedErrorData",
    "GetByOrgByRepoForbiddenError",
    "GetByOrgByRepoForbiddenErrorData",
    "GetByOrgByRepoInternalServerError",
    "GetByOrgByRepoInternalServerErrorData",
    "GetByOrgByRepoNotAcceptableError",
    "GetByOrgByRepoNotAcceptableErrorData",
    "GetByOrgByRepoNotFoundError",
    "GetByOrgByRepoNotFoundErrorData",
    "GetByOrgByRepoSyncBadRequestError",
    "GetByOrgByRepoSyncBadRequestErrorData",
    "GetByOrgByRepoSyncConflictError",
    "GetByOrgByRepoSyncConflictErrorData",
    "GetByOrgByRepoSyncForbiddenError",
    "GetByOrgByRepoSyncForbiddenErrorData",
    "GetByOrgByRepoSyncInternalServerError",
    "GetByOrgByRepoSyncInternalServerErrorData",
    "GetByOrgByRepoSyncNotAcceptableError",
    "GetByOrgByRepoSyncNotAcceptableErrorData",
    "GetByOrgByRepoSyncNotFoundError",
    "GetByOrgByRepoSyncNotFoundErrorData",
    "GetByOrgByRepoSyncUnauthorizedError",
    "GetByOrgByRepoSyncUnauthorizedErrorData",
    "GetByOrgByRepoUnauthorizedError",
    "GetByOrgByRepoUnauthorizedErrorData",
    "GetByOrgByRepoWebhooksBadRequestError",
    "GetByOrgByRepoWebhooksBadRequestErrorData",
    "GetByOrgByRepoWebhooksConflictError",
    "GetByOrgByRepoWebhooksConflictErrorData",
    "GetByOrgByRepoWebhooksForbiddenError",
    "GetByOrgByRepoWebhooksForbiddenErrorData",
    "GetByOrgByRepoWebhooksInternalServerError",
    "GetByOrgByRepoWebhooksInternalServerErrorData",
    "GetByOrgByRepoWebhooksNotAcceptableError",
    "GetByOrgByRepoWebhooksNotAcceptableErrorData",
    "GetByOrgByRepoWebhooksNotFoundError",
    "GetByOrgByRepoWebhooksNotFoundErrorData",
    "GetByOrgByRepoWebhooksUnauthorizedError",
    "GetByOrgByRepoWebhooksUnauthorizedErrorData",
    "GetByOrgConflictError",
    "GetByOrgConflictErrorData",
    "GetByOrgForbiddenError",
    "GetByOrgForbiddenErrorData",
    "GetByOrgInternalServerError",
    "GetByOrgInternalServerErrorData",
    "GetByOrgNotAcceptableError",
    "GetByOrgNotAcceptableErrorData",
    "GetByOrgNotFoundError",
    "GetByOrgNotFoundErrorData",
    "GetByOrgReposBadRequestError",
    "GetByOrgReposBadRequestErrorData",
    "GetByOrgReposConflictError",
    "GetByOrgReposConflictErrorData",
    "GetByOrgReposForbiddenError",
    "GetByOrgReposForbiddenErrorData",
    "GetByOrgReposInternalServerError",
    "GetByOrgReposInternalServerErrorData",
    "GetByOrgReposNotAcceptableError",
    "GetByOrgReposNotAcceptableErrorData",
    "GetByOrgReposNotFoundError",
    "GetByOrgReposNotFoundErrorData",
    "GetByOrgReposUnauthorizedError",
    "GetByOrgReposUnauthorizedErrorData",
    "GetByOrgUnauthorizedError",
    "GetByOrgUnauthorizedErrorData",
    "MesaDefaultError",
    "MesaError",
    "NoResponseError",
    "PatchByOrgByRepoBadRequestError",
    "PatchByOrgByRepoBadRequestErrorData",
    "PatchByOrgByRepoConflictError",
    "PatchByOrgByRepoConflictErrorData",
    "PatchByOrgByRepoForbiddenError",
    "PatchByOrgByRepoForbiddenErrorData",
    "PatchByOrgByRepoInternalServerError",
    "PatchByOrgByRepoInternalServerErrorData",
    "PatchByOrgByRepoNotAcceptableError",
    "PatchByOrgByRepoNotAcceptableErrorData",
    "PatchByOrgByRepoNotFoundError",
    "PatchByOrgByRepoNotFoundErrorData",
    "PatchByOrgByRepoUnauthorizedError",
    "PatchByOrgByRepoUnauthorizedErrorData",
    "PostByOrgAPIKeysBadRequestError",
    "PostByOrgAPIKeysBadRequestErrorData",
    "PostByOrgAPIKeysConflictError",
    "PostByOrgAPIKeysConflictErrorData",
    "PostByOrgAPIKeysForbiddenError",
    "PostByOrgAPIKeysForbiddenErrorData",
    "PostByOrgAPIKeysInternalServerError",
    "PostByOrgAPIKeysInternalServerErrorData",
    "PostByOrgAPIKeysNotAcceptableError",
    "PostByOrgAPIKeysNotAcceptableErrorData",
    "PostByOrgAPIKeysNotFoundError",
    "PostByOrgAPIKeysNotFoundErrorData",
    "PostByOrgAPIKeysUnauthorizedError",
    "PostByOrgAPIKeysUnauthorizedErrorData",
    "PostByOrgByRepoAnalyticsRefreshBadRequestError",
    "PostByOrgByRepoAnalyticsRefreshBadRequestErrorData",
    "PostByOrgByRepoAnalyticsRefreshConflictError",
    "PostByOrgByRepoAnalyticsRefreshConflictErrorData",
    "PostByOrgByRepoAnalyticsRefreshForbiddenError",
    "PostByOrgByRepoAnalyticsRefreshForbiddenErrorData",
    "PostByOrgByRepoAnalyticsRefreshInternalServerError",
    "PostByOrgByRepoAnalyticsRefreshInternalServerErrorData",
    "PostByOrgByRepoAnalyticsRefreshNotAcceptableError",
    "PostByOrgByRepoAnalyticsRefreshNotAcceptableErrorData",
    "PostByOrgByRepoAnalyticsRefreshNotFoundError",
    "PostByOrgByRepoAnalyticsRefreshNotFoundErrorData",
    "PostByOrgByRepoAnalyticsRefreshUnauthorizedError",
    "PostByOrgByRepoAnalyticsRefreshUnauthorizedErrorData",
    "PostByOrgByRepoBranchesBadRequestError",
    "PostByOrgByRepoBranchesBadRequestErrorData",
    "PostByOrgByRepoBranchesConflictError",
    "PostByOrgByRepoBranchesConflictErrorData",
    "PostByOrgByRepoBranchesForbiddenError",
    "PostByOrgByRepoBranchesForbiddenErrorData",
    "PostByOrgByRepoBranchesInternalServerError",
    "PostByOrgByRepoBranchesInternalServerErrorData",
    "PostByOrgByRepoBranchesNotAcceptableError",
    "PostByOrgByRepoBranchesNotAcceptableErrorData",
    "PostByOrgByRepoBranchesNotFoundError",
    "PostByOrgByRepoBranchesNotFoundErrorData",
    "PostByOrgByRepoBranchesUnauthorizedError",
    "PostByOrgByRepoBranchesUnauthorizedErrorData",
    "PostByOrgByRepoCommitsBadRequestError",
    "PostByOrgByRepoCommitsBadRequestErrorData",
    "PostByOrgByRepoCommitsConflictError",
    "PostByOrgByRepoCommitsConflictErrorData",
    "PostByOrgByRepoCommitsForbiddenError",
    "PostByOrgByRepoCommitsForbiddenErrorData",
    "PostByOrgByRepoCommitsInternalServerError",
    "PostByOrgByRepoCommitsInternalServerErrorData",
    "PostByOrgByRepoCommitsNotAcceptableError",
    "PostByOrgByRepoCommitsNotAcceptableErrorData",
    "PostByOrgByRepoCommitsNotFoundError",
    "PostByOrgByRepoCommitsNotFoundErrorData",
    "PostByOrgByRepoCommitsUnauthorizedError",
    "PostByOrgByRepoCommitsUnauthorizedErrorData",
    "PostByOrgByRepoSyncBadRequestError",
    "PostByOrgByRepoSyncBadRequestErrorData",
    "PostByOrgByRepoSyncConflictError",
    "PostByOrgByRepoSyncConflictErrorData",
    "PostByOrgByRepoSyncForbiddenError",
    "PostByOrgByRepoSyncForbiddenErrorData",
    "PostByOrgByRepoSyncInternalServerError",
    "PostByOrgByRepoSyncInternalServerErrorData",
    "PostByOrgByRepoSyncNotAcceptableError",
    "PostByOrgByRepoSyncNotAcceptableErrorData",
    "PostByOrgByRepoSyncNotFoundError",
    "PostByOrgByRepoSyncNotFoundErrorData",
    "PostByOrgByRepoSyncUnauthorizedError",
    "PostByOrgByRepoSyncUnauthorizedErrorData",
    "PostByOrgByRepoWebhooksBadRequestError",
    "PostByOrgByRepoWebhooksBadRequestErrorData",
    "PostByOrgByRepoWebhooksConflictError",
    "PostByOrgByRepoWebhooksConflictErrorData",
    "PostByOrgByRepoWebhooksForbiddenError",
    "PostByOrgByRepoWebhooksForbiddenErrorData",
    "PostByOrgByRepoWebhooksInternalServerError",
    "PostByOrgByRepoWebhooksInternalServerErrorData",
    "PostByOrgByRepoWebhooksNotAcceptableError",
    "PostByOrgByRepoWebhooksNotAcceptableErrorData",
    "PostByOrgByRepoWebhooksNotFoundError",
    "PostByOrgByRepoWebhooksNotFoundErrorData",
    "PostByOrgByRepoWebhooksUnauthorizedError",
    "PostByOrgByRepoWebhooksUnauthorizedErrorData",
    "PostByOrgReposBadRequestError",
    "PostByOrgReposBadRequestErrorData",
    "PostByOrgReposConflictError",
    "PostByOrgReposConflictErrorData",
    "PostByOrgReposForbiddenError",
    "PostByOrgReposForbiddenErrorData",
    "PostByOrgReposInternalServerError",
    "PostByOrgReposInternalServerErrorData",
    "PostByOrgReposNotAcceptableError",
    "PostByOrgReposNotAcceptableErrorData",
    "PostByOrgReposNotFoundError",
    "PostByOrgReposNotFoundErrorData",
    "PostByOrgReposUnauthorizedError",
    "PostByOrgReposUnauthorizedErrorData",
    "ResponseValidationError",
]

_dynamic_imports: dict[str, str] = {
    "DeleteByOrgAPIKeysByIDBadRequestError": ".deletebyorgapikeysbyidop",
    "DeleteByOrgAPIKeysByIDBadRequestErrorData": ".deletebyorgapikeysbyidop",
    "DeleteByOrgAPIKeysByIDConflictError": ".deletebyorgapikeysbyidop",
    "DeleteByOrgAPIKeysByIDConflictErrorData": ".deletebyorgapikeysbyidop",
    "DeleteByOrgAPIKeysByIDForbiddenError": ".deletebyorgapikeysbyidop",
    "DeleteByOrgAPIKeysByIDForbiddenErrorData": ".deletebyorgapikeysbyidop",
    "DeleteByOrgAPIKeysByIDInternalServerError": ".deletebyorgapikeysbyidop",
    "DeleteByOrgAPIKeysByIDInternalServerErrorData": ".deletebyorgapikeysbyidop",
    "DeleteByOrgAPIKeysByIDNotAcceptableError": ".deletebyorgapikeysbyidop",
    "DeleteByOrgAPIKeysByIDNotAcceptableErrorData": ".deletebyorgapikeysbyidop",
    "DeleteByOrgAPIKeysByIDNotFoundError": ".deletebyorgapikeysbyidop",
    "DeleteByOrgAPIKeysByIDNotFoundErrorData": ".deletebyorgapikeysbyidop",
    "DeleteByOrgAPIKeysByIDUnauthorizedError": ".deletebyorgapikeysbyidop",
    "DeleteByOrgAPIKeysByIDUnauthorizedErrorData": ".deletebyorgapikeysbyidop",
    "DeleteByOrgByRepoBranchesByBranchBadRequestError": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBranchesByBranchBadRequestErrorData": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBranchesByBranchConflictError": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBranchesByBranchConflictErrorData": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBranchesByBranchForbiddenError": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBranchesByBranchForbiddenErrorData": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBranchesByBranchInternalServerError": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBranchesByBranchInternalServerErrorData": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBranchesByBranchNotAcceptableError": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBranchesByBranchNotAcceptableErrorData": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBranchesByBranchNotFoundError": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBranchesByBranchNotFoundErrorData": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBranchesByBranchUnauthorizedError": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBranchesByBranchUnauthorizedErrorData": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBadRequestError": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoBadRequestErrorData": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoConflictError": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoConflictErrorData": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoForbiddenError": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoForbiddenErrorData": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoInternalServerError": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoInternalServerErrorData": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoNotAcceptableError": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoNotAcceptableErrorData": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoNotFoundError": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoNotFoundErrorData": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoUnauthorizedError": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoUnauthorizedErrorData": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoWebhooksByWebhookIDBadRequestError": ".deletebyorgbyrepowebhooksbywebhookidop",
    "DeleteByOrgByRepoWebhooksByWebhookIDBadRequestErrorData": ".deletebyorgbyrepowebhooksbywebhookidop",
    "DeleteByOrgByRepoWebhooksByWebhookIDConflictError": ".deletebyorgbyrepowebhooksbywebhookidop",
    "DeleteByOrgByRepoWebhooksByWebhookIDConflictErrorData": ".deletebyorgbyrepowebhooksbywebhookidop",
    "DeleteByOrgByRepoWebhooksByWebhookIDForbiddenError": ".deletebyorgbyrepowebhooksbywebhookidop",
    "DeleteByOrgByRepoWebhooksByWebhookIDForbiddenErrorData": ".deletebyorgbyrepowebhooksbywebhookidop",
    "DeleteByOrgByRepoWebhooksByWebhookIDInternalServerError": ".deletebyorgbyrepowebhooksbywebhookidop",
    "DeleteByOrgByRepoWebhooksByWebhookIDInternalServerErrorData": ".deletebyorgbyrepowebhooksbywebhookidop",
    "DeleteByOrgByRepoWebhooksByWebhookIDNotAcceptableError": ".deletebyorgbyrepowebhooksbywebhookidop",
    "DeleteByOrgByRepoWebhooksByWebhookIDNotAcceptableErrorData": ".deletebyorgbyrepowebhooksbywebhookidop",
    "DeleteByOrgByRepoWebhooksByWebhookIDNotFoundError": ".deletebyorgbyrepowebhooksbywebhookidop",
    "DeleteByOrgByRepoWebhooksByWebhookIDNotFoundErrorData": ".deletebyorgbyrepowebhooksbywebhookidop",
    "DeleteByOrgByRepoWebhooksByWebhookIDUnauthorizedError": ".deletebyorgbyrepowebhooksbywebhookidop",
    "DeleteByOrgByRepoWebhooksByWebhookIDUnauthorizedErrorData": ".deletebyorgbyrepowebhooksbywebhookidop",
    "GetByOrgAPIKeysBadRequestError": ".getbyorgapikeysop",
    "GetByOrgAPIKeysBadRequestErrorData": ".getbyorgapikeysop",
    "GetByOrgAPIKeysConflictError": ".getbyorgapikeysop",
    "GetByOrgAPIKeysConflictErrorData": ".getbyorgapikeysop",
    "GetByOrgAPIKeysForbiddenError": ".getbyorgapikeysop",
    "GetByOrgAPIKeysForbiddenErrorData": ".getbyorgapikeysop",
    "GetByOrgAPIKeysInternalServerError": ".getbyorgapikeysop",
    "GetByOrgAPIKeysInternalServerErrorData": ".getbyorgapikeysop",
    "GetByOrgAPIKeysNotAcceptableError": ".getbyorgapikeysop",
    "GetByOrgAPIKeysNotAcceptableErrorData": ".getbyorgapikeysop",
    "GetByOrgAPIKeysNotFoundError": ".getbyorgapikeysop",
    "GetByOrgAPIKeysNotFoundErrorData": ".getbyorgapikeysop",
    "GetByOrgAPIKeysUnauthorizedError": ".getbyorgapikeysop",
    "GetByOrgAPIKeysUnauthorizedErrorData": ".getbyorgapikeysop",
    "GetByOrgByRepoAgentblameBadRequestError": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameBadRequestErrorData": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameConflictError": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameConflictErrorData": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameForbiddenError": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameForbiddenErrorData": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameInternalServerError": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameInternalServerErrorData": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameNotAcceptableError": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameNotAcceptableErrorData": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameNotFoundError": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameNotFoundErrorData": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameUnauthorizedError": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameUnauthorizedErrorData": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAnalyticsBadRequestError": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsBadRequestErrorData": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsConflictError": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsConflictErrorData": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsForbiddenError": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsForbiddenErrorData": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsInternalServerError": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsInternalServerErrorData": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsNotAcceptableError": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsNotAcceptableErrorData": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsNotFoundError": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsNotFoundErrorData": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsUnauthorizedError": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsUnauthorizedErrorData": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoBranchesBadRequestError": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesBadRequestErrorData": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesConflictError": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesConflictErrorData": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesForbiddenError": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesForbiddenErrorData": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesInternalServerError": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesInternalServerErrorData": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesNotAcceptableError": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesNotAcceptableErrorData": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesNotFoundError": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesNotFoundErrorData": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesUnauthorizedError": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesUnauthorizedErrorData": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoCommitsByShaBadRequestError": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaBadRequestErrorData": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaConflictError": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaConflictErrorData": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaForbiddenError": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaForbiddenErrorData": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaInternalServerError": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaInternalServerErrorData": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaNotAcceptableError": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaNotAcceptableErrorData": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaNotFoundError": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaNotFoundErrorData": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaUnauthorizedError": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaUnauthorizedErrorData": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsBadRequestError": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsBadRequestErrorData": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsConflictError": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsConflictErrorData": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsForbiddenError": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsForbiddenErrorData": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsInternalServerError": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsInternalServerErrorData": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsNotAcceptableError": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsNotAcceptableErrorData": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsNotFoundError": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsNotFoundErrorData": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsUnauthorizedError": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsUnauthorizedErrorData": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoContentBadRequestError": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentBadRequestErrorData": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentConflictError": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentConflictErrorData": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentForbiddenError": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentForbiddenErrorData": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentInternalServerError": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentInternalServerErrorData": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentNotAcceptableError": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentNotAcceptableErrorData": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentNotFoundError": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentNotFoundErrorData": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentUnauthorizedError": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentUnauthorizedErrorData": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoDiffBadRequestError": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffBadRequestErrorData": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffConflictError": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffConflictErrorData": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffForbiddenError": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffForbiddenErrorData": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffInternalServerError": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffInternalServerErrorData": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffNotAcceptableError": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffNotAcceptableErrorData": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffNotFoundError": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffNotFoundErrorData": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffUnauthorizedError": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffUnauthorizedErrorData": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoBadRequestError": ".getbyorgbyrepoop",
    "GetByOrgByRepoBadRequestErrorData": ".getbyorgbyrepoop",
    "GetByOrgByRepoConflictError": ".getbyorgbyrepoop",
    "GetByOrgByRepoConflictErrorData": ".getbyorgbyrepoop",
    "GetByOrgByRepoForbiddenError": ".getbyorgbyrepoop",
    "GetByOrgByRepoForbiddenErrorData": ".getbyorgbyrepoop",
    "GetByOrgByRepoInternalServerError": ".getbyorgbyrepoop",
    "GetByOrgByRepoInternalServerErrorData": ".getbyorgbyrepoop",
    "GetByOrgByRepoNotAcceptableError": ".getbyorgbyrepoop",
    "GetByOrgByRepoNotAcceptableErrorData": ".getbyorgbyrepoop",
    "GetByOrgByRepoNotFoundError": ".getbyorgbyrepoop",
    "GetByOrgByRepoNotFoundErrorData": ".getbyorgbyrepoop",
    "GetByOrgByRepoUnauthorizedError": ".getbyorgbyrepoop",
    "GetByOrgByRepoUnauthorizedErrorData": ".getbyorgbyrepoop",
    "GetByOrgByRepoSyncBadRequestError": ".getbyorgbyreposyncop",
    "GetByOrgByRepoSyncBadRequestErrorData": ".getbyorgbyreposyncop",
    "GetByOrgByRepoSyncConflictError": ".getbyorgbyreposyncop",
    "GetByOrgByRepoSyncConflictErrorData": ".getbyorgbyreposyncop",
    "GetByOrgByRepoSyncForbiddenError": ".getbyorgbyreposyncop",
    "GetByOrgByRepoSyncForbiddenErrorData": ".getbyorgbyreposyncop",
    "GetByOrgByRepoSyncInternalServerError": ".getbyorgbyreposyncop",
    "GetByOrgByRepoSyncInternalServerErrorData": ".getbyorgbyreposyncop",
    "GetByOrgByRepoSyncNotAcceptableError": ".getbyorgbyreposyncop",
    "GetByOrgByRepoSyncNotAcceptableErrorData": ".getbyorgbyreposyncop",
    "GetByOrgByRepoSyncNotFoundError": ".getbyorgbyreposyncop",
    "GetByOrgByRepoSyncNotFoundErrorData": ".getbyorgbyreposyncop",
    "GetByOrgByRepoSyncUnauthorizedError": ".getbyorgbyreposyncop",
    "GetByOrgByRepoSyncUnauthorizedErrorData": ".getbyorgbyreposyncop",
    "GetByOrgByRepoWebhooksBadRequestError": ".getbyorgbyrepowebhooksop",
    "GetByOrgByRepoWebhooksBadRequestErrorData": ".getbyorgbyrepowebhooksop",
    "GetByOrgByRepoWebhooksConflictError": ".getbyorgbyrepowebhooksop",
    "GetByOrgByRepoWebhooksConflictErrorData": ".getbyorgbyrepowebhooksop",
    "GetByOrgByRepoWebhooksForbiddenError": ".getbyorgbyrepowebhooksop",
    "GetByOrgByRepoWebhooksForbiddenErrorData": ".getbyorgbyrepowebhooksop",
    "GetByOrgByRepoWebhooksInternalServerError": ".getbyorgbyrepowebhooksop",
    "GetByOrgByRepoWebhooksInternalServerErrorData": ".getbyorgbyrepowebhooksop",
    "GetByOrgByRepoWebhooksNotAcceptableError": ".getbyorgbyrepowebhooksop",
    "GetByOrgByRepoWebhooksNotAcceptableErrorData": ".getbyorgbyrepowebhooksop",
    "GetByOrgByRepoWebhooksNotFoundError": ".getbyorgbyrepowebhooksop",
    "GetByOrgByRepoWebhooksNotFoundErrorData": ".getbyorgbyrepowebhooksop",
    "GetByOrgByRepoWebhooksUnauthorizedError": ".getbyorgbyrepowebhooksop",
    "GetByOrgByRepoWebhooksUnauthorizedErrorData": ".getbyorgbyrepowebhooksop",
    "GetByOrgBadRequestError": ".getbyorgop",
    "GetByOrgBadRequestErrorData": ".getbyorgop",
    "GetByOrgConflictError": ".getbyorgop",
    "GetByOrgConflictErrorData": ".getbyorgop",
    "GetByOrgForbiddenError": ".getbyorgop",
    "GetByOrgForbiddenErrorData": ".getbyorgop",
    "GetByOrgInternalServerError": ".getbyorgop",
    "GetByOrgInternalServerErrorData": ".getbyorgop",
    "GetByOrgNotAcceptableError": ".getbyorgop",
    "GetByOrgNotAcceptableErrorData": ".getbyorgop",
    "GetByOrgNotFoundError": ".getbyorgop",
    "GetByOrgNotFoundErrorData": ".getbyorgop",
    "GetByOrgUnauthorizedError": ".getbyorgop",
    "GetByOrgUnauthorizedErrorData": ".getbyorgop",
    "GetByOrgReposBadRequestError": ".getbyorgreposop",
    "GetByOrgReposBadRequestErrorData": ".getbyorgreposop",
    "GetByOrgReposConflictError": ".getbyorgreposop",
    "GetByOrgReposConflictErrorData": ".getbyorgreposop",
    "GetByOrgReposForbiddenError": ".getbyorgreposop",
    "GetByOrgReposForbiddenErrorData": ".getbyorgreposop",
    "GetByOrgReposInternalServerError": ".getbyorgreposop",
    "GetByOrgReposInternalServerErrorData": ".getbyorgreposop",
    "GetByOrgReposNotAcceptableError": ".getbyorgreposop",
    "GetByOrgReposNotAcceptableErrorData": ".getbyorgreposop",
    "GetByOrgReposNotFoundError": ".getbyorgreposop",
    "GetByOrgReposNotFoundErrorData": ".getbyorgreposop",
    "GetByOrgReposUnauthorizedError": ".getbyorgreposop",
    "GetByOrgReposUnauthorizedErrorData": ".getbyorgreposop",
    "MesaDefaultError": ".mesadefaulterror",
    "NoResponseError": ".no_response_error",
    "PatchByOrgByRepoBadRequestError": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoBadRequestErrorData": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoConflictError": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoConflictErrorData": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoForbiddenError": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoForbiddenErrorData": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoInternalServerError": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoInternalServerErrorData": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoNotAcceptableError": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoNotAcceptableErrorData": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoNotFoundError": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoNotFoundErrorData": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoUnauthorizedError": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoUnauthorizedErrorData": ".patchbyorgbyrepoop",
    "PostByOrgAPIKeysBadRequestError": ".postbyorgapikeysop",
    "PostByOrgAPIKeysBadRequestErrorData": ".postbyorgapikeysop",
    "PostByOrgAPIKeysConflictError": ".postbyorgapikeysop",
    "PostByOrgAPIKeysConflictErrorData": ".postbyorgapikeysop",
    "PostByOrgAPIKeysForbiddenError": ".postbyorgapikeysop",
    "PostByOrgAPIKeysForbiddenErrorData": ".postbyorgapikeysop",
    "PostByOrgAPIKeysInternalServerError": ".postbyorgapikeysop",
    "PostByOrgAPIKeysInternalServerErrorData": ".postbyorgapikeysop",
    "PostByOrgAPIKeysNotAcceptableError": ".postbyorgapikeysop",
    "PostByOrgAPIKeysNotAcceptableErrorData": ".postbyorgapikeysop",
    "PostByOrgAPIKeysNotFoundError": ".postbyorgapikeysop",
    "PostByOrgAPIKeysNotFoundErrorData": ".postbyorgapikeysop",
    "PostByOrgAPIKeysUnauthorizedError": ".postbyorgapikeysop",
    "PostByOrgAPIKeysUnauthorizedErrorData": ".postbyorgapikeysop",
    "PostByOrgByRepoAnalyticsRefreshBadRequestError": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshBadRequestErrorData": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshConflictError": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshConflictErrorData": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshForbiddenError": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshForbiddenErrorData": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshInternalServerError": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshInternalServerErrorData": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshNotAcceptableError": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshNotAcceptableErrorData": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshNotFoundError": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshNotFoundErrorData": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshUnauthorizedError": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshUnauthorizedErrorData": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoBranchesBadRequestError": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoBranchesBadRequestErrorData": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoBranchesConflictError": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoBranchesConflictErrorData": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoBranchesForbiddenError": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoBranchesForbiddenErrorData": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoBranchesInternalServerError": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoBranchesInternalServerErrorData": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoBranchesNotAcceptableError": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoBranchesNotAcceptableErrorData": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoBranchesNotFoundError": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoBranchesNotFoundErrorData": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoBranchesUnauthorizedError": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoBranchesUnauthorizedErrorData": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoCommitsBadRequestError": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsBadRequestErrorData": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsConflictError": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsConflictErrorData": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsForbiddenError": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsForbiddenErrorData": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsInternalServerError": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsInternalServerErrorData": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsNotAcceptableError": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsNotAcceptableErrorData": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsNotFoundError": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsNotFoundErrorData": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsUnauthorizedError": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsUnauthorizedErrorData": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoSyncBadRequestError": ".postbyorgbyreposyncop",
    "PostByOrgByRepoSyncBadRequestErrorData": ".postbyorgbyreposyncop",
    "PostByOrgByRepoSyncConflictError": ".postbyorgbyreposyncop",
    "PostByOrgByRepoSyncConflictErrorData": ".postbyorgbyreposyncop",
    "PostByOrgByRepoSyncForbiddenError": ".postbyorgbyreposyncop",
    "PostByOrgByRepoSyncForbiddenErrorData": ".postbyorgbyreposyncop",
    "PostByOrgByRepoSyncInternalServerError": ".postbyorgbyreposyncop",
    "PostByOrgByRepoSyncInternalServerErrorData": ".postbyorgbyreposyncop",
    "PostByOrgByRepoSyncNotAcceptableError": ".postbyorgbyreposyncop",
    "PostByOrgByRepoSyncNotAcceptableErrorData": ".postbyorgbyreposyncop",
    "PostByOrgByRepoSyncNotFoundError": ".postbyorgbyreposyncop",
    "PostByOrgByRepoSyncNotFoundErrorData": ".postbyorgbyreposyncop",
    "PostByOrgByRepoSyncUnauthorizedError": ".postbyorgbyreposyncop",
    "PostByOrgByRepoSyncUnauthorizedErrorData": ".postbyorgbyreposyncop",
    "PostByOrgByRepoWebhooksBadRequestError": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksBadRequestErrorData": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksConflictError": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksConflictErrorData": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksForbiddenError": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksForbiddenErrorData": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksInternalServerError": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksInternalServerErrorData": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksNotAcceptableError": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksNotAcceptableErrorData": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksNotFoundError": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksNotFoundErrorData": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksUnauthorizedError": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksUnauthorizedErrorData": ".postbyorgbyrepowebhooksop",
    "PostByOrgReposBadRequestError": ".postbyorgreposop",
    "PostByOrgReposBadRequestErrorData": ".postbyorgreposop",
    "PostByOrgReposConflictError": ".postbyorgreposop",
    "PostByOrgReposConflictErrorData": ".postbyorgreposop",
    "PostByOrgReposForbiddenError": ".postbyorgreposop",
    "PostByOrgReposForbiddenErrorData": ".postbyorgreposop",
    "PostByOrgReposInternalServerError": ".postbyorgreposop",
    "PostByOrgReposInternalServerErrorData": ".postbyorgreposop",
    "PostByOrgReposNotAcceptableError": ".postbyorgreposop",
    "PostByOrgReposNotAcceptableErrorData": ".postbyorgreposop",
    "PostByOrgReposNotFoundError": ".postbyorgreposop",
    "PostByOrgReposNotFoundErrorData": ".postbyorgreposop",
    "PostByOrgReposUnauthorizedError": ".postbyorgreposop",
    "PostByOrgReposUnauthorizedErrorData": ".postbyorgreposop",
    "ResponseValidationError": ".responsevalidationerror",
}


def dynamic_import(modname, retries=3):
    for attempt in range(retries):
        try:
            return import_module(modname, __package__)
        except KeyError:
            # Clear any half-initialized module and retry
            sys.modules.pop(modname, None)
            if attempt == retries - 1:
                break
    raise KeyError(f"Failed to import module '{modname}' after {retries} attempts")


def __getattr__(attr_name: str) -> object:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(
            f"No {attr_name} found in _dynamic_imports for module name -> {__name__} "
        )

    try:
        module = dynamic_import(module_name)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(
            f"Failed to import {attr_name} from {module_name}: {e}"
        ) from e
    except AttributeError as e:
        raise AttributeError(
            f"Failed to get {attr_name} from {module_name}: {e}"
        ) from e


def __dir__():
    lazy_attrs = builtins.list(_dynamic_imports.keys())
    return builtins.sorted(lazy_attrs)
